@@ -9,7 +9,8 @@ from checkov.cloudformation.checks.resource.base_registry import Registry
 from checkov.cloudformation.checks.resource.registry import cfn_registry
 from checkov.cloudformation.context_parser import ContextParser, ENDLINE, STARTLINE
 from checkov.cloudformation.parser import parse, TemplateSections
-from checkov.common.parsers.node import dict_node, list_node, str_node
+from checkov.common.parallelizer.parallel_runner import parallel_runner
+from checkov.common.parsers.node import DictNode, ListNode, StrNode
 from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.runner_filter import RunnerFilter
 from checkov.common.models.consts import YAML_COMMENT_MARK
@@ -17,7 +18,7 @@ from checkov.common.models.consts import YAML_COMMENT_MARK
 CF_POSSIBLE_ENDINGS = frozenset([".yml", ".yaml", ".json", ".template"])
 
 
-def get_resource_tags(entity: Dict[str_node, dict_node], registry: Registry = cfn_registry) -> Optional[Dict[str, str]]:
+def get_resource_tags(entity: Dict[StrNode, DictNode], registry: Registry = cfn_registry) -> Optional[Dict[str, str]]:
     entity_details = registry.extract_entity_details(entity)
 
     if not entity_details:
@@ -40,8 +41,8 @@ def get_resource_tags(entity: Dict[str_node, dict_node], registry: Registry = cf
     return None
 
 
-def parse_entity_tags(tags: Union[list_node, Dict[str, Any]]) -> Optional[Dict[str, str]]:
-    if isinstance(tags, list_node):
+def parse_entity_tags(tags: Union[ListNode, Dict[str, Any]]) -> Optional[Dict[str, str]]:
+    if isinstance(tags, ListNode):
         tag_dict = {get_entity_value_as_string(tag["Key"]): get_entity_value_as_string(tag["Value"]) for tag in tags}
         return tag_dict
     elif isinstance(tags, dict):
@@ -92,7 +93,7 @@ def get_entity_value_as_string(value: Any) -> str:
 
 def get_folder_definitions(
     root_folder: str, excluded_paths: Optional[List[str]], out_parsing_errors: Dict[str, str] = {}
-) -> Tuple[Dict[str, dict_node], Dict[str, List[Tuple[int, str]]]]:
+) -> Tuple[Dict[str, DictNode], Dict[str, List[Tuple[int, str]]]]:
     files_list = []
     for root, d_names, f_names in os.walk(root_folder):
         filter_ignored_paths(root, d_names, excluded_paths)
@@ -102,29 +103,12 @@ def get_folder_definitions(
             if file_ending in CF_POSSIBLE_ENDINGS:
                 files_list.append(os.path.join(root, file))
 
-    definitions: Dict[str, dict_node] = {}
-    definitions_raw: Dict[str, List[Tuple[int, str]]] = {}
-    for file in files_list:
-        relative_file_path = f"/{os.path.relpath(file, os.path.commonprefix((root_folder, file)))}"
-        try:
-            template, template_lines = parse(file, out_parsing_errors)
-            if isinstance(template, dict_node) and isinstance(template.get("Resources"), dict_node):
-                definitions[relative_file_path] = template
-                definitions_raw[relative_file_path] = template_lines
-            else:
-                logging.debug(f"Parsed file {file} incorrectly {template}")
-        except (TypeError, ValueError) as e:
-            logging.warning(f"CloudFormation skipping {file} as it is not a valid CF template\n{e}")
-            continue
-
-    definitions = {create_file_abs_path(root_folder, file_path): v for (file_path, v) in definitions.items()}
-    definitions_raw = {create_file_abs_path(root_folder, file_path): v for (file_path, v) in definitions_raw.items()}
-
+    definitions, definitions_raw = get_files_definitions(files_list, out_parsing_errors)
     return definitions, definitions_raw
 
 
 def build_definitions_context(
-    definitions: Dict[str, dict_node], definitions_raw: Dict[str, List[Tuple[int, str]]], root_folder: str
+    definitions: Dict[str, DictNode], definitions_raw: Dict[str, List[Tuple[int, str]]], root_folder: str
 ) -> Dict[str, Dict[str, Any]]:
     definitions_context: Dict[str, Dict[str, Any]] = {}
     # iterate on the files
@@ -132,13 +116,13 @@ def build_definitions_context(
         # iterate on the definitions (Parameters, Resources, Outputs...)
         for file_path_definition, definition in file_path_definitions.items():
             if (
-                isinstance(file_path_definition, str_node)
+                isinstance(file_path_definition, StrNode)
                 and file_path_definition.upper() in TemplateSections.__members__
-                and isinstance(definition, dict_node)
+                and isinstance(definition, DictNode)
             ):
                 # iterate on the actual objects of each definition
                 for attribute, attr_value in definition.items():
-                    if isinstance(attr_value, dict_node):
+                    if isinstance(attr_value, DictNode):
                         start_line = attr_value.start_mark.line
                         end_line = attr_value.end_mark.line
                         # fix lines number for yaml and json files
@@ -175,41 +159,48 @@ def build_definitions_context(
     return definitions_context
 
 
-def create_file_abs_path(root_folder: str, cf_file: str) -> str:
-    # There are a few cases here. If -f was used, there could be a leading / because it's an absolute path,
-    # or there will be no leading slash; root_folder will always be none.
-    # If -d is used, root_folder will be the value given, and -f will start with a / (hardcoded above).
-    # The goal here is simply to get a valid path to the file (which cf_file does not always give).
-    if cf_file.startswith("/"):
-        path_to_convert = (root_folder + cf_file) if root_folder else cf_file
-    else:
-        path_to_convert = (os.path.join(root_folder, cf_file)) if root_folder else cf_file
-
-    return os.path.abspath(path_to_convert)
-
-
 def create_definitions(
     root_folder: str,
     files: Optional[List[str]] = None,
     runner_filter: RunnerFilter = RunnerFilter(),
     out_parsing_errors: Dict[str, str] = {}
-) -> Tuple[Dict[str, dict_node], Dict[str, List[Tuple[int, str]]]]:
+) -> Tuple[Dict[str, DictNode], Dict[str, List[Tuple[int, str]]]]:
     definitions = {}
     definitions_raw = {}
     if files:
-        for file in files:
-            file_ending = os.path.splitext(file)[1]
-            if file_ending in CF_POSSIBLE_ENDINGS:
-                (definitions[file], definitions_raw[file]) = parse(file, out_parsing_errors)
+        files_list = [file for file in files if os.path.splitext(file)[1] in CF_POSSIBLE_ENDINGS]
+        definitions, definitions_raw = get_files_definitions(files_list, out_parsing_errors)
 
     if root_folder:
         definitions, definitions_raw = get_folder_definitions(root_folder, runner_filter.excluded_paths, out_parsing_errors)
 
-        # Filter out empty files that have not been parsed successfully, and filter out non-CF template files
-    definitions = {
-        k: v
-        for k, v in definitions.items()
-        if v and isinstance(v, dict_node) and v.__contains__("Resources") and isinstance(v["Resources"], dict_node)
-    }
-    definitions_raw = {k: v for k, v in definitions_raw.items() if k in definitions.keys()}
+    return definitions, definitions_raw
+
+
+def get_files_definitions(files: List[str], out_parsing_errors: Dict[str, str], filepath_fn=None) \
+        -> Tuple[Dict[str, DictNode], Dict[str, List[Tuple[int, str]]]]:
+    def _parse_file(file):
+        parsing_errors = {}
+        result = parse(file, parsing_errors)
+        return (file, result), parsing_errors
+
+    results = parallel_runner.run_function(_parse_file, files)
+
+    definitions = {}
+    definitions_raw = {}
+    for result, parsing_errors in results:
+        out_parsing_errors.update(parsing_errors)
+        (file, parse_result) = result
+        path = filepath_fn(file) if filepath_fn else file
+        try:
+            template, template_lines = parse_result
+            if isinstance(template, DictNode) and isinstance(template.get("Resources"), DictNode):
+                definitions[path] = template
+                definitions_raw[path] = template_lines
+            else:
+                logging.debug(f"Parsed file {file} incorrectly {template}")
+        except (TypeError, ValueError) as e:
+            logging.warning(f"CloudFormation skipping {file} as it is not a valid CF template\n{e}")
+            continue
+
     return definitions, definitions_raw
