@@ -6,7 +6,7 @@ from checkov.cloudformation.cfn_utils import get_folder_definitions
 from checkov.cloudformation.context_parser import ContextParser
 from checkov.cloudformation.graph_builder.graph_to_definitions import convert_graph_vertices_to_definitions
 from checkov.cloudformation.graph_builder.local_graph import CloudformationLocalGraph
-from checkov.common.parsers.node import dict_node
+from checkov.common.parsers.node import DictNode
 from checkov.common.graph.db_connectors.db_connector import DBConnector
 from checkov.common.graph.graph_manager import GraphManager
 
@@ -23,7 +23,7 @@ class CloudformationGraphManager(GraphManager):
         parsing_errors: Optional[Dict[str, Exception]] = None,
         download_external_modules: bool = False,
         excluded_paths: Optional[List[str]] = None,
-    ) -> Tuple[CloudformationLocalGraph, Dict[str, dict_node]]:
+    ) -> Tuple[CloudformationLocalGraph, Dict[str, DictNode]]:
         logging.info("[CloudformationGraphManager] Parsing files in source dir {source_dir}")
         parsing_errors = {}
         definitions, definitions_raw = get_folder_definitions(source_dir, excluded_paths, parsing_errors)
@@ -43,7 +43,7 @@ class CloudformationGraphManager(GraphManager):
         return local_graph, rendered_definitions
 
     def build_graph_from_definitions(
-        self, definitions: Dict[str, dict_node], render_variables: bool = True
+        self, definitions: Dict[str, DictNode], render_variables: bool = True
     ) -> CloudformationLocalGraph:
         local_graph = CloudformationLocalGraph(definitions, source=self.source)
         local_graph.build_graph(render_variables=render_variables)
