@@ -1,5 +1,7 @@
 import os
 import re
+from pathlib import Path
+from typing import Union
 
 from colorama import init, Fore, Style
 from termcolor import colored
@@ -41,7 +43,7 @@ class Record:
         self.code_block = code_block
         self.file_path = file_path
         self.file_abs_path = file_abs_path
-        self.repo_file_path = convert_to_unix_path(f'/{os.path.relpath(file_abs_path)}')  # matches file paths given in the BC platform and should always be a unix path
+        self.repo_file_path = self._determine_repo_file_path(file_abs_path)
         self.file_line_range = file_line_range
         self.resource = resource
         self.evaluations = evaluations
@@ -51,6 +53,15 @@ class Record:
         self.caller_file_path = caller_file_path
         self.caller_file_line_range = caller_file_line_range
 
+    @staticmethod
+    def _determine_repo_file_path(file_path: Union[str, "os.PathLike[str]"]) -> str:
+        # matches file paths given in the BC platform and should always be a unix path
+        repo_file_path = Path(file_path)
+        if Path.cwd().drive == repo_file_path.drive:
+            return convert_to_unix_path(f"/{os.path.relpath(repo_file_path)}").replace("/..", "")
+
+        return f"/{'/'.join(repo_file_path.parts[1:])}"
+
     def set_guideline(self, guideline):
         self.guideline = guideline
 
@@ -60,7 +71,7 @@ class Record:
 
     def _is_expression_in_code_lines(self, expression):
         stripped_expression = self._trim_special_chars(expression)
-        return any([stripped_expression in self._trim_special_chars(line) for (_, line) in self.code_block])
+        return any(stripped_expression in self._trim_special_chars(line) for (_, line) in self.code_block)
 
     @staticmethod
     def _code_line_string(code_block):
