@@ -25,7 +25,7 @@ class ServerlessRegistry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if runner_filter.should_run_check(check.id):
+            if runner_filter.should_run_check(check.id, check.bc_id):
                 self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
                 result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
                                    entity_name=entity_type, entity_type=entity_type, skip_info=skip_info)
