@@ -8,6 +8,7 @@ import dpath.util
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
+from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.models.enums import CheckResult
 from checkov.common.output.graph_record import GraphRecord
 from checkov.common.output.record import Record
@@ -85,15 +86,7 @@ class Runner(BaseRunner):
                 files = [os.path.abspath(file) for file in files]
                 root_folder = os.path.split(os.path.commonprefix(files))[0]
                 self.parser.evaluate_variables = False
-                for file in files:
-                    if file.endswith(".tf") or (scan_hcl and file.endswith(".hcl")):
-                        file_parsing_errors = {}
-                        parse_result = self.parser.parse_file(file=file, parsing_errors=file_parsing_errors, scan_hcl=scan_hcl)
-                        if parse_result is not None:
-                            self.definitions[file] = parse_result
-                        if file_parsing_errors:
-                            parsing_errors.update(file_parsing_errors)
-                            continue
+                self._parse_files(files, scan_hcl, parsing_errors)
                 local_graph = self.graph_manager.build_graph_from_definitions(self.definitions)
             else:
                 raise Exception("Root directory was not specified, files were not specified")
@@ -139,24 +132,26 @@ class Runner(BaseRunner):
                             copy_of_check_result['suppress_comment'] = skipped_check['suppress_comment']
                             break
                     copy_of_check_result['entity'] = entity.get(CustomAttributes.CONFIG)
-                    record = Record(check_id=check.id,
-                                    bc_check_id=check.bc_id,
-                                    check_name=check.name,
-                                    check_result=copy_of_check_result,
-                                    code_block=entity_context.get('code_lines'),
-                                    file_path=f"/{os.path.relpath(full_file_path, root_folder)}",
-                                    file_line_range=[entity_context.get('start_line'),
-                                                     entity_context.get('end_line')],
-                                    resource=".".join(entity_context['definition_path']),
-                                    entity_tags=entity.get('tags', {}),
-                                    evaluations=entity_evaluations,
-                                    check_class=check.__class__.__module__,
-                                    file_abs_path=os.path.abspath(full_file_path))
+                    record = Record(
+                        check_id=check.id,
+                        bc_check_id=check.bc_id,
+                        check_name=check.name,
+                        check_result=copy_of_check_result,
+                        code_block=entity_context.get('code_lines'),
+                        file_path=f"/{os.path.relpath(full_file_path, root_folder)}",
+                        file_line_range=[entity_context.get('start_line'),
+                                         entity_context.get('end_line')],
+                        resource=".".join(entity_context['definition_path']),
+                        entity_tags=entity.get('tags', {}),
+                        evaluations=entity_evaluations,
+                        check_class=check.__class__.__module__,
+                        file_abs_path=os.path.abspath(full_file_path)
+                    )
                     if self.breadcrumbs:
                         breadcrumb = self.breadcrumbs.get(record.file_path, {}).get(record.resource)
                         if breadcrumb:
                             record = GraphRecord(record, breadcrumb)
-
+                    record.set_guideline(check.guideline)
                     report.add_record(record=record)
         return report
 
@@ -295,8 +290,29 @@ class Runner(BaseRunner):
                 breadcrumb = self.breadcrumbs.get(record.file_path, {}).get('.'.join([entity_type, entity_name]))
                 if breadcrumb:
                     record = GraphRecord(record, breadcrumb)
+                record.set_guideline(check.guideline)
                 report.add_record(record=record)
 
+    def _parse_files(self, files, scan_hcl, parsing_errors):
+        def parse_file(file):
+            if not (file.endswith(".tf") or (scan_hcl and file.endswith(".hcl"))):
+                return
+            file_parsing_errors = {}
+            parse_result = self.parser.parse_file(file=file, parsing_errors=file_parsing_errors, scan_hcl=scan_hcl)
+            # the exceptions type can un-pickleable so we need to cast them to Exception
+            for path, e in file_parsing_errors.items():
+                file_parsing_errors[path] = Exception(str(e))
+            return file, parse_result, file_parsing_errors
+
+        results = parallel_runner.run_function(parse_file, files)
+        for result in results:
+            if result:
+                file, parse_result, file_parsing_errors = result
+                if parse_result is not None:
+                    self.definitions[file] = parse_result
+                if file_parsing_errors:
+                    parsing_errors.update(file_parsing_errors)
+
     @staticmethod
     def push_skipped_checks_down(self, definition_context, module_path, skipped_checks):
         # this method pushes the skipped_checks down the 1 level to all resource types.
